@@ -3,16 +3,14 @@ package commit
 import (
 	"fmt"
 
+	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/git/log"
-
-	pb "gitlab.com/gitlab-org/gitaly-proto/go"
-
 	"golang.org/x/net/context"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 )
 
-func (s *server) LastCommitForPath(ctx context.Context, in *pb.LastCommitForPathRequest) (*pb.LastCommitForPathResponse, error) {
+func (s *server) LastCommitForPath(ctx context.Context, in *gitalypb.LastCommitForPathRequest) (*gitalypb.LastCommitForPathResponse, error) {
 	if err := validateLastCommitForPathRequest(in); err != nil {
 		return nil, status.Errorf(codes.InvalidArgument, "LastCommitForPath: %v", err)
 	}
@@ -27,10 +25,10 @@ func (s *server) LastCommitForPath(ctx context.Context, in *pb.LastCommitForPath
 		return nil, err
 	}
 
-	return &pb.LastCommitForPathResponse{Commit: commit}, nil
+	return &gitalypb.LastCommitForPathResponse{Commit: commit}, nil
 }
 
-func validateLastCommitForPathRequest(in *pb.LastCommitForPathRequest) error {
+func validateLastCommitForPathRequest(in *gitalypb.LastCommitForPathRequest) error {
 	if len(in.Revision) == 0 {
 		return fmt.Errorf("empty Revision")
 	}
