@@ -6,11 +6,10 @@ import (
 	"io"
 	"testing"
 
-	pb "gitlab.com/gitlab-org/gitaly-proto/go"
+	"github.com/stretchr/testify/require"
+	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/diff"
 	"gitlab.com/gitlab-org/gitaly/internal/testhelper"
-
-	"github.com/stretchr/testify/require"
 	"golang.org/x/net/context"
 	"google.golang.org/grpc/codes"
 )
@@ -27,7 +26,7 @@ func TestSuccessfulCommitDiffRequest(t *testing.T) {
 
 	rightCommit := "ab2c9622c02288a2bbaaf35d96088cfdff31d9d9"
 	leftCommit := "8a0f2ee90d940bfb0ba1e14e8214b0649056e4ab"
-	rpcRequest := &pb.CommitDiffRequest{Repository: testRepo, RightCommitId: rightCommit, LeftCommitId: leftCommit, IgnoreWhitespaceChange: false}
+	rpcRequest := &gitalypb.CommitDiffRequest{Repository: testRepo, RightCommitId: rightCommit, LeftCommitId: leftCommit, IgnoreWhitespaceChange: false}
 
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
@@ -191,7 +190,7 @@ func TestSuccessfulCommitDiffRequestWithPaths(t *testing.T) {
 
 	rightCommit := "e4003da16c1c2c3fc4567700121b17bf8e591c6c"
 	leftCommit := "8a0f2ee90d940bfb0ba1e14e8214b0649056e4ab"
-	rpcRequest := &pb.CommitDiffRequest{
+	rpcRequest := &gitalypb.CommitDiffRequest{
 		Repository:             testRepo,
 		RightCommitId:          rightCommit,
 		LeftCommitId:           leftCommit,
@@ -269,7 +268,7 @@ func TestSuccessfulCommitDiffRequestWithTypeChangeDiff(t *testing.T) {
 
 	rightCommit := "184a47d38677e2e439964859b877ae9bc424ab11"
 	leftCommit := "80d56eb72ba5d77fd8af857eced17a7d0640cb82"
-	rpcRequest := &pb.CommitDiffRequest{
+	rpcRequest := &gitalypb.CommitDiffRequest{
 		Repository:    testRepo,
 		RightCommitId: rightCommit,
 		LeftCommitId:  leftCommit,
@@ -402,12 +401,12 @@ func TestSuccessfulCommitDiffRequestWithIgnoreWhitespaceChange(t *testing.T) {
 
 	for _, entry := range pathsAndDiffs {
 		t.Run(entry.desc, func(t *testing.T) {
-			rpcRequest := &pb.CommitDiffRequest{
+			rpcRequest := &gitalypb.CommitDiffRequest{
 				Repository:             testRepo,
 				RightCommitId:          rightCommit,
 				LeftCommitId:           leftCommit,
 				IgnoreWhitespaceChange: true,
-				Paths: entry.paths,
+				Paths:                  entry.paths,
 			}
 
 			ctx, cancel := context.WithCancel(context.Background())
@@ -436,18 +435,18 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 	leftCommit := "184a47d38677e2e439964859b877ae9bc424ab11"
 
 	type diffAttributes struct {
-		path                      string
-		collapsed, overflowMarker bool
+		path                                string
+		collapsed, overflowMarker, tooLarge bool
 	}
 
 	requestsAndResults := []struct {
 		desc    string
-		request pb.CommitDiffRequest
+		request gitalypb.CommitDiffRequest
 		result  []diffAttributes
 	}{
 		{
 			desc: "no enforcement",
-			request: pb.CommitDiffRequest{
+			request: gitalypb.CommitDiffRequest{
 				EnforceLimits: false,
 			},
 			result: []diffAttributes{
@@ -460,11 +459,12 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 		},
 		{
 			desc: "max file count enforcement",
-			request: pb.CommitDiffRequest{
+			request: gitalypb.CommitDiffRequest{
 				EnforceLimits: true,
 				MaxFiles:      3,
 				MaxLines:      1000,
 				MaxBytes:      3 * 5 * 1024,
+				MaxPatchBytes: 100000,
 			},
 			result: []diffAttributes{
 				{path: "CHANGELOG"},
@@ -475,11 +475,12 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 		},
 		{
 			desc: "max line count enforcement",
-			request: pb.CommitDiffRequest{
+			request: gitalypb.CommitDiffRequest{
 				EnforceLimits: true,
 				MaxFiles:      5,
 				MaxLines:      90,
 				MaxBytes:      5 * 5 * 1024,
+				MaxPatchBytes: 100000,
 			},
 			result: []diffAttributes{
 				{path: "CHANGELOG"},
@@ -489,11 +490,12 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 		},
 		{
 			desc: "max byte count enforcement",
-			request: pb.CommitDiffRequest{
+			request: gitalypb.CommitDiffRequest{
 				EnforceLimits: true,
 				MaxFiles:      5,
 				MaxLines:      1000,
 				MaxBytes:      6900,
+				MaxPatchBytes: 100000,
 			},
 			result: []diffAttributes{
 				{path: "CHANGELOG"},
@@ -505,7 +507,7 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 		},
 		{
 			desc: "no collapse",
-			request: pb.CommitDiffRequest{
+			request: gitalypb.CommitDiffRequest{
 				EnforceLimits: true,
 				CollapseDiffs: false,
 				MaxFiles:      3,
@@ -514,6 +516,7 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 				SafeMaxFiles:  1,
 				SafeMaxLines:  1000,
 				SafeMaxBytes:  1 * 5 * 1024,
+				MaxPatchBytes: 100000,
 			},
 			result: []diffAttributes{
 				{path: "CHANGELOG"},
@@ -522,9 +525,30 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 				{overflowMarker: true},
 			},
 		},
+		{
+			desc: "set as too large when exceeding single patch limit",
+			request: gitalypb.CommitDiffRequest{
+				EnforceLimits: true,
+				CollapseDiffs: false,
+				MaxFiles:      5,
+				MaxLines:      1000,
+				MaxBytes:      3 * 5 * 1024,
+				SafeMaxFiles:  3,
+				SafeMaxLines:  1000,
+				SafeMaxBytes:  1 * 5 * 1024,
+				MaxPatchBytes: 1200,
+			},
+			result: []diffAttributes{
+				{path: "CHANGELOG", tooLarge: true},
+				{path: "CONTRIBUTING.md", tooLarge: true},
+				{path: "LICENSE", tooLarge: false},
+				{path: "PROCESS.md", tooLarge: true},
+				{path: "VERSION", tooLarge: false},
+			},
+		},
 		{
 			desc: "collapse after safe max file count is exceeded",
-			request: pb.CommitDiffRequest{
+			request: gitalypb.CommitDiffRequest{
 				EnforceLimits: true,
 				CollapseDiffs: true,
 				MaxFiles:      3,
@@ -533,6 +557,7 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 				SafeMaxFiles:  1,
 				SafeMaxLines:  1000,
 				SafeMaxBytes:  1 * 5 * 1024,
+				MaxPatchBytes: 100000,
 			},
 			result: []diffAttributes{
 				{path: "CHANGELOG"},
@@ -543,7 +568,7 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 		},
 		{
 			desc: "collapse after safe max line count is exceeded",
-			request: pb.CommitDiffRequest{
+			request: gitalypb.CommitDiffRequest{
 				EnforceLimits: true,
 				CollapseDiffs: true,
 				MaxFiles:      5,
@@ -552,6 +577,7 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 				SafeMaxFiles:  5,
 				SafeMaxLines:  40,
 				SafeMaxBytes:  5 * 5 * 1024,
+				MaxPatchBytes: 100000,
 			},
 			result: []diffAttributes{
 				{path: "CHANGELOG", collapsed: true},
@@ -563,7 +589,7 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 		},
 		{
 			desc: "collapse after safe max byte count is exceeded",
-			request: pb.CommitDiffRequest{
+			request: gitalypb.CommitDiffRequest{
 				EnforceLimits: true,
 				CollapseDiffs: true,
 				MaxFiles:      4,
@@ -572,6 +598,7 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 				SafeMaxFiles:  4,
 				SafeMaxLines:  1000,
 				SafeMaxBytes:  4830,
+				MaxPatchBytes: 100000,
 			},
 			result: []diffAttributes{
 				{path: "CHANGELOG"},
@@ -602,16 +629,14 @@ func TestSuccessfulCommitDiffRequestWithLimits(t *testing.T) {
 
 			require.Equal(t, len(requestAndResult.result), len(receivedDiffs), "number of diffs received")
 			for i, diff := range receivedDiffs {
-				if overflowMarker := requestAndResult.result[i].overflowMarker; overflowMarker {
-					require.Equal(t, overflowMarker, diff.OverflowMarker, "overflow marker")
-					continue
-				}
+				expectedDiff := requestAndResult.result[i]
 
-				require.Equal(t, requestAndResult.result[i].path, string(diff.FromPath), "path")
+				require.Equal(t, expectedDiff.overflowMarker, diff.OverflowMarker, "%s overflow marker", diff.FromPath)
+				require.Equal(t, expectedDiff.tooLarge, diff.TooLarge, "%s too large", diff.FromPath)
+				require.Equal(t, expectedDiff.path, string(diff.FromPath), "%s path", diff.FromPath)
+				require.Equal(t, expectedDiff.collapsed, diff.Collapsed, "%s collapsed", diff.FromPath)
 
-				collapsed := requestAndResult.result[i].collapsed
-				require.Equal(t, collapsed, diff.Collapsed, "%s collapsed", requestAndResult.result[i].path)
-				if collapsed {
+				if expectedDiff.collapsed {
 					require.Empty(t, diff.Patch, "patch")
 				}
 			}
@@ -632,11 +657,11 @@ func TestFailedCommitDiffRequestDueToValidationError(t *testing.T) {
 	rightCommit := "d42783470dc29fde2cf459eb3199ee1d7e3f3a72"
 	leftCommit := rightCommit + "~" // Parent of rightCommit
 
-	rpcRequests := []pb.CommitDiffRequest{
-		{Repository: &pb.Repository{StorageName: "fake", RelativePath: "path"}, RightCommitId: rightCommit, LeftCommitId: leftCommit}, // Repository doesn't exist
-		{Repository: nil, RightCommitId: rightCommit, LeftCommitId: leftCommit},                                                       // Repository is nil
-		{Repository: testRepo, RightCommitId: "", LeftCommitId: leftCommit},                                                           // RightCommitId is empty
-		{Repository: testRepo, RightCommitId: rightCommit, LeftCommitId: ""},                                                          // LeftCommitId is empty
+	rpcRequests := []gitalypb.CommitDiffRequest{
+		{Repository: &gitalypb.Repository{StorageName: "fake", RelativePath: "path"}, RightCommitId: rightCommit, LeftCommitId: leftCommit}, // Repository doesn't exist
+		{Repository: nil, RightCommitId: rightCommit, LeftCommitId: leftCommit},                                                             // Repository is nil
+		{Repository: testRepo, RightCommitId: "", LeftCommitId: leftCommit},                                                                 // RightCommitId is empty
+		{Repository: testRepo, RightCommitId: rightCommit, LeftCommitId: ""},                                                                // LeftCommitId is empty
 	}
 
 	for _, rpcRequest := range rpcRequests {
@@ -667,7 +692,7 @@ func TestFailedCommitDiffRequestWithNonExistentCommit(t *testing.T) {
 
 	nonExistentCommitID := "deadfacedeadfacedeadfacedeadfacedeadface"
 	leftCommit := nonExistentCommitID + "~" // Parent of rightCommit
-	rpcRequest := &pb.CommitDiffRequest{Repository: testRepo, RightCommitId: nonExistentCommitID, LeftCommitId: leftCommit}
+	rpcRequest := &gitalypb.CommitDiffRequest{Repository: testRepo, RightCommitId: nonExistentCommitID, LeftCommitId: leftCommit}
 
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
@@ -692,7 +717,7 @@ func TestSuccessfulCommitDeltaRequest(t *testing.T) {
 
 	rightCommit := "742518b2be68fc750bb4c357c0df821a88113286"
 	leftCommit := "8a0f2ee90d940bfb0ba1e14e8214b0649056e4ab"
-	rpcRequest := &pb.CommitDeltaRequest{Repository: testRepo, RightCommitId: rightCommit, LeftCommitId: leftCommit}
+	rpcRequest := &gitalypb.CommitDeltaRequest{Repository: testRepo, RightCommitId: rightCommit, LeftCommitId: leftCommit}
 
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
@@ -815,7 +840,7 @@ func TestSuccessfulCommitDeltaRequestWithPaths(t *testing.T) {
 
 	rightCommit := "e4003da16c1c2c3fc4567700121b17bf8e591c6c"
 	leftCommit := "8a0f2ee90d940bfb0ba1e14e8214b0649056e4ab"
-	rpcRequest := &pb.CommitDeltaRequest{
+	rpcRequest := &gitalypb.CommitDeltaRequest{
 		Repository:    testRepo,
 		RightCommitId: rightCommit,
 		LeftCommitId:  leftCommit,
@@ -885,11 +910,11 @@ func TestFailedCommitDeltaRequestDueToValidationError(t *testing.T) {
 	rightCommit := "d42783470dc29fde2cf459eb3199ee1d7e3f3a72"
 	leftCommit := rightCommit + "~" // Parent of rightCommit
 
-	rpcRequests := []pb.CommitDeltaRequest{
-		{Repository: &pb.Repository{StorageName: "fake", RelativePath: "path"}, RightCommitId: rightCommit, LeftCommitId: leftCommit}, // Repository doesn't exist
-		{Repository: nil, RightCommitId: rightCommit, LeftCommitId: leftCommit},                                                       // Repository is nil
-		{Repository: testRepo, RightCommitId: "", LeftCommitId: leftCommit},                                                           // RightCommitId is empty
-		{Repository: testRepo, RightCommitId: rightCommit, LeftCommitId: ""},                                                          // LeftCommitId is empty
+	rpcRequests := []gitalypb.CommitDeltaRequest{
+		{Repository: &gitalypb.Repository{StorageName: "fake", RelativePath: "path"}, RightCommitId: rightCommit, LeftCommitId: leftCommit}, // Repository doesn't exist
+		{Repository: nil, RightCommitId: rightCommit, LeftCommitId: leftCommit},                                                             // Repository is nil
+		{Repository: testRepo, RightCommitId: "", LeftCommitId: leftCommit},                                                                 // RightCommitId is empty
+		{Repository: testRepo, RightCommitId: rightCommit, LeftCommitId: ""},                                                                // LeftCommitId is empty
 	}
 
 	for _, rpcRequest := range rpcRequests {
@@ -920,7 +945,7 @@ func TestFailedCommitDeltaRequestWithNonExistentCommit(t *testing.T) {
 
 	nonExistentCommitID := "deadfacedeadfacedeadfacedeadfacedeadface"
 	leftCommit := nonExistentCommitID + "~" // Parent of rightCommit
-	rpcRequest := &pb.CommitDeltaRequest{Repository: testRepo, RightCommitId: nonExistentCommitID, LeftCommitId: leftCommit}
+	rpcRequest := &gitalypb.CommitDeltaRequest{Repository: testRepo, RightCommitId: nonExistentCommitID, LeftCommitId: leftCommit}
 
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
@@ -933,7 +958,7 @@ func TestFailedCommitDeltaRequestWithNonExistentCommit(t *testing.T) {
 	testhelper.RequireGrpcError(t, err, codes.Unavailable)
 }
 
-func drainCommitDiffResponse(c pb.Diff_CommitDiffClient) error {
+func drainCommitDiffResponse(c gitalypb.DiffService_CommitDiffClient) error {
 	for {
 		_, err := c.Recv()
 		if err != nil {
@@ -942,7 +967,7 @@ func drainCommitDiffResponse(c pb.Diff_CommitDiffClient) error {
 	}
 }
 
-func drainCommitDeltaResponse(c pb.Diff_CommitDeltaClient) error {
+func drainCommitDeltaResponse(c gitalypb.DiffService_CommitDeltaClient) error {
 	for {
 		_, err := c.Recv()
 		if err != nil {
@@ -951,7 +976,7 @@ func drainCommitDeltaResponse(c pb.Diff_CommitDeltaClient) error {
 	}
 }
 
-func getDiffsFromCommitDiffClient(t *testing.T, client pb.DiffService_CommitDiffClient) []*diff.Diff {
+func getDiffsFromCommitDiffClient(t *testing.T, client gitalypb.DiffService_CommitDiffClient) []*diff.Diff {
 	var diffs []*diff.Diff
 	var currentDiff *diff.Diff
 
@@ -975,6 +1000,7 @@ func getDiffsFromCommitDiffClient(t *testing.T, client pb.DiffService_CommitDiff
 				Collapsed:      fetchedDiff.Collapsed,
 				OverflowMarker: fetchedDiff.OverflowMarker,
 				Patch:          fetchedDiff.RawPatchData,
+				TooLarge:       fetchedDiff.TooLarge,
 			}
 		} else {
 			currentDiff.Patch = append(currentDiff.Patch, fetchedDiff.RawPatchData...)
@@ -989,7 +1015,7 @@ func getDiffsFromCommitDiffClient(t *testing.T, client pb.DiffService_CommitDiff
 	return diffs
 }
 
-func assertExactReceivedDiffs(t *testing.T, client pb.DiffService_CommitDiffClient, expectedDiffs []diff.Diff) {
+func assertExactReceivedDiffs(t *testing.T, client gitalypb.DiffService_CommitDiffClient, expectedDiffs []diff.Diff) {
 	fetchedDiffs := getDiffsFromCommitDiffClient(t, client)
 
 	var i int
@@ -1041,7 +1067,7 @@ func assertExactReceivedDiffs(t *testing.T, client pb.DiffService_CommitDiffClie
 	}
 }
 
-func assertExactReceivedDeltas(t *testing.T, client pb.Diff_CommitDeltaClient, expectedDeltas []diff.Diff) {
+func assertExactReceivedDeltas(t *testing.T, client gitalypb.DiffService_CommitDeltaClient, expectedDeltas []diff.Diff) {
 	i := 0
 	for {
 		fetchedDeltas, err := client.Recv()
