@@ -1,7 +1,7 @@
 package diff
 
 import (
-	pb "gitlab.com/gitlab-org/gitaly-proto/go"
+	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/rubyserver"
 )
 
@@ -13,7 +13,7 @@ type server struct {
 }
 
 // NewServer creates a new instance of a gRPC DiffServer
-func NewServer(rs *rubyserver.Server) pb.DiffServiceServer {
+func NewServer(rs *rubyserver.Server) gitalypb.DiffServiceServer {
 	return &server{
 		MsgSizeThreshold: msgSizeThreshold,
 		Server:           rs,
