@@ -1,9 +1,6 @@
 package operations_test
 
 import (
-	"io/ioutil"
-	"os"
-	"path"
 	"strings"
 	"testing"
 
@@ -101,12 +98,11 @@ func TestFailedUserRebaseRequestDueToPreReceiveError(t *testing.T) {
 	}
 
 	hookContent := []byte("#!/bin/sh\necho GL_ID=$GL_ID\nexit 1")
-
 	for _, hookName := range operations.GitlabPreHooks {
 		t.Run(hookName, func(t *testing.T) {
-			hookPath := path.Join(testRepoPath, "hooks", hookName)
-			require.NoError(t, ioutil.WriteFile(hookPath, hookContent, 0755))
-			defer os.Remove(hookPath)
+			remove, err := operations.OverrideHooks(hookName, hookContent)
+			require.NoError(t, err)
+			defer remove()
 
 			md := testhelper.GitalyServersMetadata(t, serverSocketPath)
 			ctx := metadata.NewOutgoingContext(ctxOuter, md)
