@@ -2,13 +2,13 @@ package ssh
 
 import (
 	"fmt"
-	"os/exec"
 
 	"github.com/grpc-ecosystem/go-grpc-middleware/logging/logrus"
 	log "github.com/sirupsen/logrus"
 	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 	"gitlab.com/gitlab-org/gitaly/internal/command"
 	"gitlab.com/gitlab-org/gitaly/internal/git"
+	"gitlab.com/gitlab-org/gitaly/internal/git/hooks"
 	"gitlab.com/gitlab-org/gitaly/internal/helper"
 	"gitlab.com/gitlab-org/gitaly/streamio"
 	"google.golang.org/grpc/codes"
@@ -51,16 +51,18 @@ func (s *server) SSHReceivePack(stream gitalypb.SSHService_SSHReceivePackServer)
 	if req.GlRepository != "" {
 		env = append(env, fmt.Sprintf("GL_REPOSITORY=%s", req.GlRepository))
 	}
-	env = git.AddGitProtocolEnv(ctx, req, env)
 
 	repoPath, err := helper.GetRepoPath(req.Repository)
 	if err != nil {
 		return err
 	}
 
-	gitOptions := git.BuildGitOptions(req.GitConfigOptions, "receive-pack", repoPath)
-	osCommand := exec.Command(command.GitPath(), gitOptions...)
-	cmd, err := command.New(ctx, osCommand, stdin, stdout, stderr, env...)
+	env = git.AddGitProtocolEnv(ctx, req, env)
+	env = append(env, command.GitEnv...)
+
+	opts := append([]string{fmt.Sprintf("core.hooksPath=%s", hooks.Path())}, req.GitConfigOptions...)
+	gitOptions := git.BuildGitOptions(opts, "receive-pack", repoPath)
+	cmd, err := git.BareCommand(ctx, stdin, stdout, stderr, env, gitOptions...)
 
 	if err != nil {
 		return status.Errorf(codes.Unavailable, "SSHReceivePack: cmd: %v", err)
