@@ -131,9 +131,7 @@ module GitalyServer
               y << Gitaly::UserMergeBranchResponse.new(commit_id: commit_id)
 
               second_request = session.next
-              unless second_request.apply
-                raise GRPC::FailedPrecondition.new('merge aborted by client')
-              end
+              raise GRPC::FailedPrecondition.new('merge aborted by client') unless second_request.apply
             end
 
             y << Gitaly::UserMergeBranchResponse.new(branch_update: branch_update_result(result))
@@ -300,6 +298,52 @@ module GitalyServer
       end
     end
 
+    def user_apply_patch(call)
+      bridge_exceptions do
+        stream = call.each_remote_read
+        first_request = stream.next
+
+        header = first_request.header
+        user = Gitlab::Git::User.from_gitaly(header.user)
+        target_branch = header.target_branch
+        patches = stream.lazy.map(&:patches)
+
+        branch_update = Gitlab::Git::Repository.from_gitaly_with_block(header.repository, call) do |repo|
+          begin
+            Gitlab::Git::CommitPatches.new(user, repo, target_branch, patches).commit
+          rescue Gitlab::Git::PatchError => e
+            raise GRPC::FailedPrecondition.new(e.message)
+          end
+        end
+
+        Gitaly::UserApplyPatchResponse.new(branch_update: branch_update_result(branch_update))
+      end
+    end
+
+    def user_update_submodule(request, call)
+      bridge_exceptions do
+        user = Gitlab::Git::User.from_gitaly(request.user)
+
+        begin
+          branch_update = Gitlab::Git::Repository.from_gitaly_with_block(request.repository, call) do |repo|
+            begin
+              Gitlab::Git::Submodule
+                .new(user, repo, request.submodule, request.branch)
+                .update(request.commit_sha, request.commit_message.dup)
+            rescue ArgumentError => e
+              raise GRPC::InvalidArgument.new(e.to_s)
+            end
+          end
+
+          Gitaly::UserUpdateSubmoduleResponse.new(branch_update: branch_update_result(branch_update))
+        rescue Gitlab::Git::CommitError => e
+          Gitaly::UserUpdateSubmoduleResponse.new(commit_error: set_utf8!(e.message))
+        rescue Gitlab::Git::PreReceiveError => e
+          Gitaly::UserUpdateSubmoduleResponse.new(pre_receive_error: set_utf8!(e.message))
+        end
+      end
+    end
+
     private
 
     def commit_files_opts(call, header, actions)
@@ -309,9 +353,7 @@ module GitalyServer
         actions: actions
       }
 
-      if header.start_repository
-        opts[:start_repository] = Gitlab::Git::GitalyRemoteRepository.new(header.start_repository, call)
-      end
+      opts[:start_repository] = Gitlab::Git::GitalyRemoteRepository.new(header.start_repository, call) if header.start_repository
 
       optional_fields = {
         start_branch_name: 'start_branch_name',
