@@ -61,6 +61,7 @@ module Gitlab
     OSError = Class.new(BaseError)
     UnknownRef = Class.new(BaseError)
     PreReceiveError = Class.new(BaseError)
+    PatchError = Class.new(BaseError)
 
     class << self
       include Gitlab::EncodingHelper
@@ -71,11 +72,7 @@ module Gitlab
 
       def branch_name(ref)
         ref = ref.to_s
-        if self.branch_ref?(ref)
-          self.ref_name(ref)
-        else
-          nil
-        end
+        self.ref_name(ref) if self.branch_ref?(ref)
       end
 
       def committer_hash(email:, name:)
@@ -90,11 +87,7 @@ module Gitlab
 
       def tag_name(ref)
         ref = ref.to_s
-        if self.tag_ref?(ref)
-          self.ref_name(ref)
-        else
-          nil
-        end
+        self.ref_name(ref) if self.tag_ref?(ref)
       end
 
       def tag_ref?(ref)
@@ -116,9 +109,7 @@ module Gitlab
       def check_namespace!(*objects)
         expected_namespace = self.name + '::'
         objects.each do |object|
-          unless object.class.name.start_with?(expected_namespace)
-            raise ArgumentError, "expected object in #{expected_namespace}, got #{object}"
-          end
+          raise ArgumentError, "expected object in #{expected_namespace}, got #{object}" unless object.class.name.start_with?(expected_namespace)
         end
       end
 
