@@ -1,3 +1,5 @@
+require 'securerandom'
+
 module Gitlab
   module Git
     # These are monkey patches on top of the vendored version of Repository.
@@ -15,27 +17,23 @@ module Gitlab
         GIT_OBJECT_DIRECTORY_RELATIVE
         GIT_ALTERNATE_OBJECT_DIRECTORIES_RELATIVE
       ].freeze
-      SEARCH_CONTEXT_LINES = 3
-      REV_LIST_COMMIT_LIMIT = 2_000
       # In https://gitlab.com/gitlab-org/gitaly/merge_requests/698
       # We copied these two prefixes into gitaly-go, so don't change these
       # or things will break! (REBASE_WORKTREE_PREFIX and SQUASH_WORKTREE_PREFIX)
       REBASE_WORKTREE_PREFIX = 'rebase'.freeze
       SQUASH_WORKTREE_PREFIX = 'squash'.freeze
+      AM_WORKTREE_PREFIX = 'am'.freeze
       GITALY_INTERNAL_URL = 'ssh://gitaly/internal.git'.freeze
       GITLAB_PROJECTS_TIMEOUT = Gitlab.config.gitlab_shell.git_timeout
-      EMPTY_REPOSITORY_CHECKSUM = '0000000000000000000000000000000000000000'.freeze
       AUTOCRLF_VALUES = { 'true' => true, 'false' => false, 'input' => :input }.freeze
+      RUGGED_KEY = :rugged_list
 
       NoRepository = Class.new(StandardError)
-      InvalidRepository = Class.new(StandardError)
-      InvalidBlobName = Class.new(StandardError)
       InvalidRef = Class.new(StandardError)
       GitError = Class.new(StandardError)
       DeleteBranchError = Class.new(StandardError)
       CreateTreeError = Class.new(StandardError)
       TagExistsError = Class.new(StandardError)
-      ChecksumError = Class.new(StandardError)
 
       class << self
         def from_gitaly(gitaly_repository, call)
@@ -48,14 +46,26 @@ module Gitlab
           )
         end
 
+        def from_gitaly_with_block(gitaly_repository, call)
+          repository = from_gitaly(gitaly_repository, call)
+
+          result = yield repository
+
+          repository.cleanup
+
+          result
+        end
+
         def create(repo_path)
-          FileUtils.mkdir_p(repo_path, mode: 0770)
+          FileUtils.mkdir_p(repo_path, mode: 0o770)
 
           # Equivalent to `git --git-path=#{repo_path} init [--bare]`
           repo = Rugged::Repository.init_at(repo_path, true)
           repo.close
 
-          symlink_hooks_to = Gitlab.config.gitlab_shell.hooks_path
+          # TODO: remove this when self healing hooks has been merged at least
+          # one release ago: https://gitlab.com/gitlab-org/gitaly/merge_requests/886
+          symlink_hooks_to = Gitlab::Git::Hook.directory
           create_hooks(repo_path, symlink_hooks_to) if symlink_hooks_to.present?
         end
 
@@ -75,7 +85,8 @@ module Gitlab
               # Move the existing hooks somewhere safe
               FileUtils.mv(
                 local_hooks_path,
-                "#{local_hooks_path}.old.#{Time.now.to_i}")
+                "#{local_hooks_path}.old.#{Time.now.to_i}"
+              )
             end
 
             # Create the hooks symlink
@@ -91,17 +102,14 @@ module Gitlab
       # Directory name of repo
       attr_reader :name
 
-      # Relative path of repo
-      attr_reader :relative_path
-
       attr_reader :gitlab_projects, :storage, :gl_repository, :relative_path
 
-      def initialize(gitaly_repository, path, gl_repository, gitlab_projects, combined_alt_dirs="")
+      def initialize(gitaly_repository, path, gl_repository, gitlab_projects, combined_alt_dirs = "")
         @gitaly_repository = gitaly_repository
 
         @alternate_object_directories = combined_alt_dirs
-          .split(File::PATH_SEPARATOR)
-          .map { |d| File.join(path, d) }
+                                        .split(File::PATH_SEPARATOR)
+                                        .map { |d| File.join(path, d) }
 
         @storage = gitaly_repository.storage_name
         @relative_path = gitaly_repository.relative_path
@@ -116,7 +124,7 @@ module Gitlab
 
       def add_branch(branch_name, user:, target:)
         target_object = Ref.dereference_object(lookup(target))
-        raise InvalidRef.new("target not found: #{target}") unless target_object
+        raise InvalidRef, "target not found: #{target}" unless target_object
 
         OperationService.new(user, self).add_branch(branch_name, target_object.oid)
         find_branch(branch_name)
@@ -124,13 +132,9 @@ module Gitlab
         raise InvalidRef, ex
       end
 
-      def gitaly_repository
-        @gitaly_repository
-      end
+      attr_reader :gitaly_repository
 
-      def alternate_object_directories
-        @alternate_object_directories
-      end
+      attr_reader :alternate_object_directories
 
       def sort_branches(branches, sort_by)
         case sort_by
@@ -149,13 +153,6 @@ module Gitlab
         end
       end
 
-      # TODO: Can be removed once https://gitlab.com/gitlab-org/gitaly/merge_requests/738
-      #       is well and truly out in the wild.
-      def fsck
-        msg, status = run_git(%W[--git-dir=#{path} fsck], nice: true)
-        raise GitError.new("Could not fsck repository: #{msg}") unless status.zero?
-      end
-
       def exists?
         File.exist?(File.join(path, 'refs'))
       end
@@ -165,9 +162,13 @@ module Gitlab
       end
 
       def rugged
-        Rugged::Repository.new(path, alternates: alternate_object_directories)
+        @rugged ||= begin
+                      Rugged::Repository.new(path, alternates: alternate_object_directories).tap do |repo|
+                        Thread.current[RUGGED_KEY] << repo if Thread.current[RUGGED_KEY]
+                      end
+                    end
       rescue Rugged::RepositoryError, Rugged::OSError
-        raise NoRepository.new('no repository for such path')
+        raise NoRepository, 'no repository for such path'
       end
 
       def branch_names
@@ -201,10 +202,6 @@ module Gitlab
         end
       end
 
-      def tag_names
-        rugged.tags.map { |t| t.name }
-      end
-
       def tags
         rugged.references.each("refs/tags/*").map do |ref|
           message = nil
@@ -212,18 +209,15 @@ module Gitlab
           if ref.target.is_a?(Rugged::Tag::Annotation)
             tag_message = ref.target.message
 
-            if tag_message.respond_to?(:chomp)
-              message = tag_message.chomp
-            end
+            message = tag_message.chomp if tag_message.respond_to?(:chomp)
           end
 
           target_commit = Gitlab::Git::Commit.find(self, ref.target)
-          Gitlab::Git::Tag.new(self, {
-            name: ref.name,
-            target: ref.target,
-            target_commit: target_commit,
-            message: message
-          })
+          Gitlab::Git::Tag.new(self,
+                               name: ref.name,
+                               target: ref.target,
+                               target_commit: target_commit,
+                               message: message)
         end.sort_by(&:name)
       end
 
@@ -279,7 +273,7 @@ module Gitlab
 
             result = []
 
-            Open3.popen3(*git_diff_cmd(old_rev, new_rev)) do |stdin, stdout, _stderr, wait_thr|
+            Open3.popen3(*git_diff_cmd(old_rev, new_rev)) do |_stdin, stdout, _stderr, wait_thr|
               cat_stdin, cat_stdout, cat_stderr, cat_wait_thr = Open3.popen3(*git_cat_file_cmd)
 
               stdout.each_line do |line|
@@ -292,15 +286,13 @@ module Gitlab
               cat_stdout.close
               cat_stderr.close
 
-              unless [cat_wait_thr, wait_thr].all? { |waiter| waiter.value&.success? }
-                raise ::Gitlab::Git::Repository::GitError, "Unabled to obtain changes between #{old_rev} and #{new_rev}"
-              end
+              raise ::Gitlab::Git::Repository::GitError, "Unabled to obtain changes between #{old_rev} and #{new_rev}" unless [cat_wait_thr, wait_thr].all? { |waiter| waiter.value&.success? }
             end
 
             result
           end
       rescue ArgumentError => e
-        raise Gitlab::Git::Repository::GitError.new(e.to_s)
+        raise Gitlab::Git::Repository::GitError, e.to_s
       end
 
       def parse_raw_diff_line(line)
@@ -314,16 +306,14 @@ module Gitlab
         new_blob_id.gsub!(/[^\h]/, '')
 
         # We can't pass '0000000...' to `git cat-file` given it will not return info about the deleted file
-        blob_id = new_blob_id =~ /\A0+\z/ ? old_blob_id : new_blob_id
+        blob_id = new_blob_id.match?(/\A0+\z/) ? old_blob_id : new_blob_id
 
         [old_mode, new_mode, blob_id, rest]
       end
 
       def add_tag(tag_name, user:, target:, message: nil)
         target_object = Ref.dereference_object(lookup(target))
-        raise InvalidRef.new("target not found: #{target}") unless target_object
-
-        user = Gitlab::Git::User.from_gitlab(user) unless user.respond_to?(:gl_id)
+        raise InvalidRef, "target not found: #{target}" unless target_object
 
         options = nil # Use nil, not the empty hash. Rugged cares about this.
         if message
@@ -349,7 +339,7 @@ module Gitlab
       def rm_branch(branch_name, user:)
         branch = find_branch(branch_name)
 
-        raise InvalidRef.new("branch not found: #{branch_name}") unless branch
+        raise InvalidRef, "branch not found: #{branch_name}" unless branch
 
         OperationService.new(user, self).rm_branch(branch)
       end
@@ -357,16 +347,17 @@ module Gitlab
       def rm_tag(tag_name, user:)
         tag = find_tag(tag_name)
 
-        raise InvalidRef.new("tag not found: #{tag_name}") unless tag
+        raise InvalidRef, "tag not found: #{tag_name}" unless tag
 
         Gitlab::Git::OperationService.new(user, self).rm_tag(tag)
       end
 
       def find_tag(name)
-        tags.find { |tag| tag.name == name }
+        name_b = name.b
+        tags.find { |tag| tag.name.b == name_b }
       end
 
-      def merge(user, source_sha, target_branch, message, &block)
+      def merge(user, source_sha, target_branch, message)
         committer = Gitlab::Git.committer_hash(email: user.email, name: user.name)
 
         OperationService.new(user, self).with_branch(target_branch) do |start_commit|
@@ -443,12 +434,12 @@ module Gitlab
       end
 
       def diff_exists?(sha1, sha2)
-        rugged.diff(sha1, sha2).size > 0
+        rugged.diff(sha1, sha2).size.positive?
       end
 
       def rebase(user, rebase_id, branch:, branch_sha:, remote_repository:, remote_branch:)
         rebase_path = worktree_path(REBASE_WORKTREE_PREFIX, rebase_id)
-        env = git_env_for_user(user)
+        env = git_env.merge(user.git_env)
 
         if remote_repository.is_a?(RemoteRepository)
           env.merge!(remote_repository.fetch_env)
@@ -459,11 +450,11 @@ module Gitlab
 
         with_worktree(rebase_path, branch, env: env) do
           run_git!(
-            %W(pull --rebase #{remote_repo_path} #{remote_branch}),
+            %W[pull --rebase #{remote_repo_path} #{remote_branch}],
             chdir: rebase_path, env: env
           )
 
-          rebase_sha = run_git!(%w(rev-parse HEAD), chdir: rebase_path, env: env).strip
+          rebase_sha = run_git!(%w[rev-parse HEAD], chdir: rebase_path, env: env).strip
 
           update_branch(branch, user: user, newrev: rebase_sha, oldrev: branch_sha)
 
@@ -473,36 +464,79 @@ module Gitlab
 
       def squash(user, squash_id, branch:, start_sha:, end_sha:, author:, message:)
         squash_path = worktree_path(SQUASH_WORKTREE_PREFIX, squash_id)
-        env = git_env_for_user(user).merge(
+        env = git_env.merge(user.git_env).merge(
           'GIT_AUTHOR_NAME' => author.name,
           'GIT_AUTHOR_EMAIL' => author.email
         )
         diff_range = "#{start_sha}...#{end_sha}"
         diff_files = run_git!(
-          %W(diff --name-only --diff-filter=ar --binary #{diff_range})
+          %W[diff --name-only --diff-filter=ar --binary #{diff_range}]
         ).chomp
 
         with_worktree(squash_path, branch, sparse_checkout_files: diff_files, env: env) do
           # Apply diff of the `diff_range` to the worktree
-          diff = run_git!(%W(diff --binary #{diff_range}))
-          run_git!(%w(apply --index --whitespace=nowarn), chdir: squash_path, env: env) do |stdin|
+          diff = run_git!(%W[diff --binary #{diff_range}])
+          run_git!(%w[apply --index --whitespace=nowarn], chdir: squash_path, env: env) do |stdin|
             stdin.binmode
             stdin.write(diff)
           end
 
           # Commit the `diff_range` diff
-          run_git!(%W(commit --no-verify --message #{message}), chdir: squash_path, env: env)
+          run_git!(%W[commit --no-verify --message #{message}], chdir: squash_path, env: env)
 
           # Return the squash sha. May print a warning for ambiguous refs, but
           # we can ignore that with `--quiet` and just take the SHA, if present.
           # HEAD here always refers to the current HEAD commit, even if there is
           # another ref called HEAD.
           run_git!(
-            %w(rev-parse --quiet --verify HEAD), chdir: squash_path, env: env
+            %w[rev-parse --quiet --verify HEAD], chdir: squash_path, env: env
           ).chomp
         end
       end
 
+      def commit_patches(start_point, patches, extra_env: {})
+        worktree_path = worktree_path(AM_WORKTREE_PREFIX, SecureRandom.hex)
+        env = git_env.merge(extra_env)
+
+        with_worktree(worktree_path, start_point, env: env) do
+          result, status = run_git(%w[am --quiet --3way], chdir: worktree_path, env: env) do |stdin|
+            loop { stdin.write(patches.next) }
+          end
+
+          raise Gitlab::Git::PatchError, result unless status == 0
+
+          run_git!(
+            %w[rev-parse --quiet --verify HEAD], chdir: worktree_path, env: env
+          ).chomp
+        end
+      end
+
+      def update_submodule(submodule_path, commit_sha, branch, committer, message)
+        target = rugged.rev_parse(branch)
+        raise CommitError, 'Invalid branch' unless target.is_a?(Rugged::Commit)
+
+        current_entry = rugged_submodule_entry(target, submodule_path)
+        raise CommitError, 'Invalid submodule path' unless current_entry
+        raise CommitError, "The submodule #{submodule_path} is already at #{commit_sha}" if commit_sha == current_entry[:oid]
+
+        commit_tree = target.tree.update([action: :upsert,
+                                          oid: commit_sha,
+                                          filemode: 0o160000,
+                                          path: submodule_path])
+
+        options = {
+          parents: [target.oid],
+          tree: commit_tree,
+          message: message,
+          author: committer,
+          committer: committer
+        }
+
+        create_commit(options).tap do |result|
+          raise CommitError, 'Failed to create commit' unless result
+        end
+      end
+
       def push_remote_branches(remote_name, branch_names, forced: true)
         success = @gitlab_projects.push_branches(remote_name, GITLAB_PROJECTS_TIMEOUT, forced, branch_names)
 
@@ -518,7 +552,8 @@ module Gitlab
       def multi_action(
         user, branch_name:, message:, actions:,
         author_email: nil, author_name: nil,
-        start_branch_name: nil, start_repository: self)
+        start_branch_name: nil, start_repository: self
+      )
 
         OperationService.new(user, self).with_branch(
           branch_name,
@@ -582,7 +617,8 @@ module Gitlab
             yield branch_commit
           else
             with_repo_tmp_commit(
-              start_repository, start_branch_name, start_commit_id) do |tmp_commit|
+              start_repository, start_branch_name, start_commit_id
+            ) do |tmp_commit|
               yield tmp_commit
             end
           end
@@ -592,9 +628,7 @@ module Gitlab
       def with_repo_tmp_commit(start_repository, start_branch_name, sha)
         source_ref = start_branch_name
 
-        unless Gitlab::Git.branch_ref?(source_ref)
-          source_ref = "#{Gitlab::Git::BRANCH_REF_PREFIX}#{source_ref}"
-        end
+        source_ref = "#{Gitlab::Git::BRANCH_REF_PREFIX}#{source_ref}" unless Gitlab::Git.branch_ref?(source_ref)
 
         tmp_ref = fetch_ref(
           start_repository,
@@ -688,7 +722,7 @@ module Gitlab
         Gitlab::Git.check_namespace!(source_repository)
         source_repository = RemoteRepository.new(source_repository) unless source_repository.is_a?(RemoteRepository)
 
-        args = %W(fetch --no-tags -f #{GITALY_INTERNAL_URL} #{source_ref}:#{target_ref})
+        args = %W[fetch --no-tags -f #{GITALY_INTERNAL_URL} #{source_ref}:#{target_ref}]
         message, status = run_git(args, env: source_repository.fetch_env)
         raise Gitlab::Git::CommandError, message if status != 0
 
@@ -734,9 +768,7 @@ module Gitlab
         # the case of mirrors we map its refs (that would usualy go under
         # [remote_name]/) to the top level namespace. We clean the mapping so
         # those don't get deleted.
-        if rugged.config["remote.#{remote_name}.mirror"]
-          rugged.config.delete("remote.#{remote_name}.fetch")
-        end
+        rugged.config.delete("remote.#{remote_name}.fetch") if rugged.config["remote.#{remote_name}.mirror"]
 
         rugged.remotes.delete(remote_name)
         true
@@ -801,13 +833,17 @@ module Gitlab
 
         args.push('--objects') if objects
 
-        if options.any?
-          args.push(*options)
-        end
+        args.push(*options) if options.any?
 
         run_git!(args, lazy_block: block)
       end
 
+      def cleanup
+        # Opening a repository may be expensive, and we only need to close it
+        # if it's been open.
+        rugged&.close if defined?(@rugged)
+      end
+
       private
 
       def run_git(args, chdir: path, env: {}, nice: false, lazy_block: nil, &block)
@@ -815,9 +851,7 @@ module Gitlab
         cmd.unshift("nice") if nice
 
         object_directories = alternate_object_directories
-        if object_directories.any?
-          env['GIT_ALTERNATE_OBJECT_DIRECTORIES'] = object_directories.join(File::PATH_SEPARATOR)
-        end
+        env['GIT_ALTERNATE_OBJECT_DIRECTORIES'] = object_directories.join(File::PATH_SEPARATOR) if object_directories.any?
 
         popen(cmd, chdir, env, lazy_block: lazy_block, &block)
       end
@@ -830,15 +864,8 @@ module Gitlab
         output
       end
 
-      def run_git_with_timeout(args, timeout, env: {})
-        popen_with_timeout([Gitlab.config.git.bin_path, *args], timeout, path, env)
-      end
-
-      def git_env_for_user(user)
+      def git_env
         {
-          'GIT_COMMITTER_NAME' => user.name,
-          'GIT_COMMITTER_EMAIL' => user.email,
-          'GL_ID' => Gitlab::GlId.gl_id(user),
           'GL_PROTOCOL' => Gitlab::Git::Hook::GL_PROTOCOL,
           'GL_REPOSITORY' => gl_repository
         }
@@ -910,14 +937,14 @@ module Gitlab
       def build_git_cmd(*args)
         object_directories = alternate_object_directories.join(File::PATH_SEPARATOR)
 
-        env = { 'PWD' => self.path }
+        env = { 'PWD' => path }
         env['GIT_ALTERNATE_OBJECT_DIRECTORIES'] = object_directories if object_directories.present?
 
         [
           env,
           ::Gitlab.config.git.bin_path,
           *args,
-          { chdir: self.path }
+          { chdir: path }
         ]
       end
 
@@ -941,9 +968,7 @@ module Gitlab
           stdin.write(instructions.join)
         end
 
-        unless status.zero?
-          raise GitError.new("Could not delete refs #{ref_names}: #{message}")
-        end
+        raise GitError, "Could not delete refs #{ref_names}: #{message}" unless status.zero?
       end
 
       def rugged_cherry_pick(user:, commit:, branch_name:, message:, start_branch_name:, start_repository:)
@@ -962,9 +987,9 @@ module Gitlab
 
           create_commit(message: message,
                         author: {
-                            email: commit.author_email,
-                            name: commit.author_name,
-                            time: commit.authored_date
+                          email: commit.author_email,
+                          name: commit.author_name,
+                          time: commit.authored_date
                         },
                         committer: committer,
                         tree: cherry_pick_tree_id,
@@ -1017,7 +1042,7 @@ module Gitlab
       end
 
       def with_worktree(worktree_path, branch, sparse_checkout_files: nil, env:)
-        base_args = %w(worktree add --detach)
+        base_args = %w[worktree add --detach]
 
         # Note that we _don't_ want to test for `.present?` here: If the caller
         # passes an non nil empty value it means it still wants sparse checkout
@@ -1026,12 +1051,12 @@ module Gitlab
         if sparse_checkout_files
           # Create worktree without checking out
           run_git!(base_args + ['--no-checkout', worktree_path], env: env)
-          worktree_git_path = run_git!(%w(rev-parse --git-dir), chdir: worktree_path).chomp
+          worktree_git_path = run_git!(%w[rev-parse --git-dir], chdir: worktree_path).chomp
 
           configure_sparse_checkout(worktree_git_path, sparse_checkout_files)
 
           # After sparse checkout configuration, checkout `branch` in worktree
-          run_git!(%W(checkout --detach #{branch}), chdir: worktree_path, env: env)
+          run_git!(%W[checkout --detach #{branch}], chdir: worktree_path, env: env)
         else
           # Create worktree and checkout `branch` in it
           run_git!(base_args + [worktree_path, branch], env: env)
@@ -1047,7 +1072,7 @@ module Gitlab
       # this can be very expensive, so set up sparse checkout for the worktree
       # to only check out the files we're interested in.
       def configure_sparse_checkout(worktree_git_path, files)
-        run_git!(%w(config core.sparseCheckout true))
+        run_git!(%w[config core.sparseCheckout true])
 
         return if files.empty?
 
@@ -1086,6 +1111,22 @@ module Gitlab
       def rev_list_param(spec)
         spec == :all ? ['--all'] : spec
       end
+
+      def rugged_submodule_entry(target, submodule_path)
+        parent_dir = File.dirname(submodule_path)
+        parent_dir = '' if parent_dir == '.'
+        parent_tree = rugged.rev_parse("#{target.oid}^{tree}:#{parent_dir}")
+
+        return unless parent_tree.is_a?(Rugged::Tree)
+
+        current_entry = parent_tree[File.basename(submodule_path)]
+
+        valid_submodule_entry?(current_entry) ? current_entry : nil
+      end
+
+      def valid_submodule_entry?(entry)
+        entry && entry[:type] == :commit
+      end
     end
   end
 end
